==> xoonips-3.41.zip: xoonips-3.41/xoonips/filesearch/def_ppt.php <==
<?php
// $Revision: 1.2.2.1.2.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/**
 * definition file of MS-PowerPoint 2003 file search
 */
// php-indent: disable
$module['class_name']    = 'XoonipsPpt';
$module['php_file_name'] = 'ppt.php';
$module['name']          = 'ppt';
$module['display_name']  = 'ppt';

$module['mime_type']     = array( 'application/vnd.ms-powerpoint', 'application/msword' );
$module['extensions']    = array( 'ppt' );
$module['version']       = '1.0';
// php-indent: enable
?>

==> xoonips-3.43.zip: xoonips-3.43/xoonips/filesearch/def_ppt.php <==
<?php
// $Revision: 1.2.2.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2009 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/**
 * definition file of MS-PowerPoint 2003 file search
 */
// php-indent: disable
$module['class_name']    = 'XooNIpsFileSearchPluginPPT';
$module['php_file_name'] = 'ppt.php';
$module['name']          = 'ppt';
$module['display_name']  = 'MS-PowerPoint 95/97/2000/XP/2003';
$module['mime_type']     = array( 'application/vnd.ms-powerpoint', 'application/msword' );
$module['extensions']    = array( 'ppt' );
$module['version']       = '2.0';
// php-indent: enable
?>
